==> cdi-tck-impl-1.2.2.Final-sources.jar: org/jboss/cdi/tck/tests/implementation/simple/resource/persistenceContext/staticProducer/PersistenceInjectionStaticProducerFieldTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.implementation.simple.resource.persistenceContext.staticProducer;

import static org.jboss.cdi.tck.TestGroups.INTEGRATION;
import static org.jboss.cdi.tck.TestGroups.PERSISTENCE;
import static org.jboss.cdi.tck.cdi.Sections.DECLARING_RESOURCE;

import javax.enterprise.context.spi.CreationalContext;
import javax.enterprise.inject.spi.Bean;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

/**
 * Test producer fields with injection of persistence related objects.
 * 
 * @author David Allen
 * @author Martin Kouba
 */
@SpecVersion(spec = "cdi", version = "1.1 Final Release")
public class PersistenceInjectionStaticProducerFieldTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(PersistenceInjectionStaticProducerFieldTest.class)
                .withDefaultPersistenceXml().build();
    }

    @Test(groups = { INTEGRATION, PERSISTENCE })
    @SpecAssertion(section = DECLARING_RESOURCE, id = "cc")
    public void testInjectionOfPersistenceContext() {
        ServiceBean serviceBean = getContextualReference(ServiceBean.class);
        ManagedBean managedBean = serviceBean.getManagedBean();
        assert managedBean.getPersistenceContext() != null : "Persistence context was not injected into bean";
        assert serviceBean.validateEntityManager();
    }

    @Test(groups = { INTEGRATION, PERSISTENCE })
    @SpecAssertion(section = DECLARING_RESOURCE, id = "dd")
    public void testInjectionOfPersistenceUnit() {
        Bean<ManagedBean> managedBeanBean = getBeans(ManagedBean.class).iterator().next();
        CreationalContext<ManagedBean> managedBeanCc = getCurrentManager().createCreationalContext(managedBeanBean);
        ManagedBean managedBean = managedBeanBean.create(managedBeanCc);
        assert managedBean.getPersistenceUnit() != null : "Persistence unit was not injected into bean";
        assert managedBean.getPersistenceUnit().isOpen() : "Persistence unit not open injected into bean";
    }
}

==> cdi-tck-impl-2.0.0.Final-sources.jar: org/jboss/cdi/tck/tests/implementation/simple/resource/persistenceContext/staticProducer/PersistenceInjectionStaticProducerFieldTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.implementation.simple.resource.persistenceContext.staticProducer;

import static org.jboss.cdi.tck.TestGroups.INTEGRATION;
import static org.jboss.cdi.tck.TestGroups.PERSISTENCE;
import static org.jboss.cdi.tck.cdi.Sections.DECLARING_RESOURCE;

import javax.enterprise.context.spi.CreationalContext;
import javax.enterprise.inject.spi.Bean;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

/**
 * Test producer fields with injection of persistence related objects.
 * 
 * @author David Allen
 * @author Martin Kouba
 */
@SpecVersion(spec = "cdi", version = "2.0-PFD")
public class PersistenceInjectionStaticProducerFieldTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(PersistenceInjectionStaticProducerFieldTest.class)
                .withDefaultPersistenceXml().build();
    }

    @Test(groups = { INTEGRATION, PERSISTENCE })
    @SpecAssertion(section = DECLARING_RESOURCE, id = "cc")
    public void testInjectionOfPersistenceContext() {
        ServiceBean serviceBean = getContextualReference(ServiceBean.class);
        ManagedBean managedBean = serviceBean.getManagedBean();
        assert managedBean.getPersistenceContext() != null : "Persistence context was not injected into bean";
        assert serviceBean.validateEntityManager();
    }

    @Test(groups = { INTEGRATION, PERSISTENCE })
    @SpecAssertion(section = DECLARING_RESOURCE, id = "dd")
    public void testInjectionOfPersistenceUnit() {
        Bean<ManagedBean> managedBeanBean = getBeans(ManagedBean.class).iterator().next();
        CreationalContext<ManagedBean> managedBeanCc = getCurrentManager().createCreationalContext(managedBeanBean);
        ManagedBean managedBean = managedBeanBean.create(managedBeanCc);
        assert managedBean.getPersistenceUnit() != null : "Persistence unit was not injected into bean";
        assert managedBean.getPersistenceUnit().isOpen() : "Persistence unit not open injected into bean";
    }
}
